@@ -1,5 +1,5 @@
 from enum import StrEnum
-from maleo.types.string import ListOfStrings
+from maleo.types.string import ListOfStrs
 
 
 class KeyType(StrEnum):
@@ -7,7 +7,7 @@ class KeyType(StrEnum):
     PUBLIC = "public"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
@@ -16,5 +16,5 @@ class Loader(StrEnum):
     PYCRYPTODOME = "pycryptodome"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
